<!-- These are examples of badges you might want to add to your README:
     please update the URLs accordingly

[![Built Status](https://api.cirrus-ci.com/github/<USER>/batt-utility.svg?branch=main)](https://cirrus-ci.com/github/<USER>/batt-utility)
[![ReadTheDocs](https://readthedocs.org/projects/batt-utility/badge/?version=latest)](https://batt-utility.readthedocs.io/en/stable/)
[![Coveralls](https://img.shields.io/coveralls/github/<USER>/batt-utility/main.svg)](https://coveralls.io/r/<USER>/batt-utility)
[![PyPI-Server](https://img.shields.io/pypi/v/batt-utility.svg)](https://pypi.org/project/batt-utility/)
[![Conda-Forge](https://img.shields.io/conda/vn/conda-forge/batt-utility.svg)](https://anaconda.org/conda-forge/batt-utility)
[![Monthly Downloads](https://pepy.tech/badge/batt-utility/month)](https://pepy.tech/project/batt-utility)
[![Twitter](https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter)](https://twitter.com/batt-utility)
-->

[![Project generated with PyScaffold](https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold)](https://pyscaffold.org/)

# batt-utility

> Utility functions for OpenBattTools

A longer description of your project goes here...

## Disclaimer
This is a work in progress. The code is not yet fully tested and may contain bugs. Use at your own risk.

### Installation
```cmd
pip install batt-utility
```

## Contributing
Contributions are welcome and manged with issue tracking and pull requests.

<!-- pyscaffold-notes -->

## Note

This project has been set up using PyScaffold 4.5. For details and usage
information on PyScaffold see https://pyscaffold.org/.
